====================================
README for HydraTK DataGen extension
====================================

| DataGen extension provides utilities for data generation.

| Following generators are supported.

* ASN.1: encoder/decoder with ASN.1 specification
* JSON: sample generator from JSON specification
* XML: sample generator from WSDL/XSD specification